==> ij-segment-wrapper-3.4.0.tgz: package/lib/segmentWrapper.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import { infojobsVisitorIdFactory } from './infojobsVisitor/factory';
var TCF_API_VERSION = 2;
export function getVisitorIdCallback(_ref) {
  var host = _ref.host,
    getCookie = _ref.getCookie,
    setCookie = _ref.setCookie;
  var infojobsVisitorIdUseCase = infojobsVisitorIdFactory({
    getCookie: getCookie,
    setCookie: setCookie,
    host: host
  });
  return function () {
    if (window.__mpi.visitorId) return Promise.resolve(window.__mpi.visitorId);

    // useractioncomplete when the user accepts or declines the consents
    // tcloaded when the user did already accept or decline the consents
    return new Promise(function (resolve) {
      window.__tcfapi('addEventListener', TCF_API_VERSION, /*#__PURE__*/function () {
        var _ref3 = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee(_ref2) {
          var eventStatus, isEvent, visitor;
          return _regeneratorRuntime.wrap(function _callee$(_context) {
            while (1) switch (_context.prev = _context.next) {
              case 0:
                eventStatus = _ref2.eventStatus;
                isEvent = ['useractioncomplete', 'tcloaded'].includes(eventStatus);
                if (isEvent) {
                  _context.next = 4;
                  break;
                }
                return _context.abrupt("return", Promise.resolve());
              case 4:
                _context.next = 6;
                return infojobsVisitorIdUseCase.execute();
              case 6:
                visitor = _context.sent;
                window.__mpi.visitorId = visitor.visitorId;
                return _context.abrupt("return", resolve(visitor.visitorId));
              case 9:
              case "end":
                return _context.stop();
            }
          }, _callee);
        }));
        return function (_x) {
          return _ref3.apply(this, arguments);
        };
      }());
    });
  };
}
function getSite(_ref4) {
  var _ref4$host = _ref4.host,
    host = _ref4$host === void 0 ? window.location.host : _ref4$host;
  return host.indexOf('infojobs.it') > -1 ? 'infojobs.it' : 'infojobs.net';
}
function getTenant(_ref5) {
  var _ref5$host = _ref5.host,
    host = _ref5$host === void 0 ? window.location.host : _ref5$host;
  return host.includes('infojobs.it') ? 'infojobs_it' : 'infojobs';
}
function getGoogleAnalyticsConfigByEnv(_ref6) {
  var _ref6$env = _ref6.env,
    env = _ref6$env === void 0 ? 'production' : _ref6$env,
    host = _ref6.host;
  if (env !== 'production') {
    return {};
  }
  return {
    googleAnalyticsMeasurementId: 'G-7SHGGRXFWG',
    googleAnalyticsConfig: {
      user_properties: {
        tenant: getTenant({
          host: host
        })
      }
    }
  };
}
export default (function (dependencies) {
  var _window$__mpi$segment, _window$__mpi$segment2, _window$__mpi$segment3;
  window.__SEGMENT_WRAPPER = {
    ADOBE_ORG_ID: '05FF6243578784B37F000101@AdobeOrg',
    TRACKING_SERVER: 'schibstedspain.d3.sc.omtrdc.net'
  };

  // will be accessed by the segment-wrapper
  window.__mpi = window.__mpi || {};
  window.__mpi.segmentWrapper = _extends({}, window.__mpi.segmentWrapper, getGoogleAnalyticsConfigByEnv(dependencies), {
    defaultProperties: _extends({}, (_window$__mpi$segment = window.__mpi.segmentWrapper) == null ? void 0 : _window$__mpi$segment.defaultProperties, {
      site: getSite(dependencies),
      vertical: 'jobs'
    }),
    defaultContext: _extends({}, (_window$__mpi$segment2 = window.__mpi.segmentWrapper) == null ? void 0 : _window$__mpi$segment2.defaultContext, {
      site: getSite(dependencies)
    }),
    getCustomAdobeVisitorId: getVisitorIdCallback(dependencies),
    tcfTrackDefaultProperties: _extends({}, (_window$__mpi$segment3 = window.__mpi.segmentWrapper) == null ? void 0 : _window$__mpi$segment3.tcfTrackDefaultProperties, {
      vertical: 'jobs'
    })
  });
});

==> ij-segment-wrapper-3.7.0.tgz: package/lib/segmentWrapper.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import { infojobsVisitorIdFactory } from './infojobsVisitor/factory';
var TCF_API_VERSION = 2;
export function getVisitorIdCallback(_ref) {
  var host = _ref.host,
    getCookie = _ref.getCookie,
    setCookie = _ref.setCookie;
  var infojobsVisitorIdUseCase = infojobsVisitorIdFactory({
    getCookie: getCookie,
    setCookie: setCookie,
    host: host
  });
  return function () {
    if (window.__mpi.visitorId) return Promise.resolve(window.__mpi.visitorId);

    // useractioncomplete when the user accepts or declines the consents
    // tcloaded when the user did already accept or decline the consents
    return new Promise(function (resolve) {
      window.__tcfapi('addEventListener', TCF_API_VERSION, /*#__PURE__*/function () {
        var _ref3 = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee(_ref2) {
          var eventStatus, isEvent, visitor;
          return _regeneratorRuntime.wrap(function _callee$(_context) {
            while (1) switch (_context.prev = _context.next) {
              case 0:
                eventStatus = _ref2.eventStatus;
                isEvent = ['useractioncomplete', 'tcloaded'].includes(eventStatus);
                if (isEvent) {
                  _context.next = 4;
                  break;
                }
                return _context.abrupt("return", Promise.resolve());
              case 4:
                _context.next = 6;
                return infojobsVisitorIdUseCase.execute();
              case 6:
                visitor = _context.sent;
                window.__mpi.visitorId = visitor.visitorId;
                return _context.abrupt("return", resolve(visitor.visitorId));
              case 9:
              case "end":
                return _context.stop();
            }
          }, _callee);
        }));
        return function (_x) {
          return _ref3.apply(this, arguments);
        };
      }());
    });
  };
}
function getSite(_ref4) {
  var _ref4$host = _ref4.host,
    host = _ref4$host === void 0 ? window.location.host : _ref4$host;
  return host.indexOf('infojobs.it') > -1 ? 'infojobs.it' : 'infojobs.net';
}
function getTenant(_ref5) {
  var _ref5$host = _ref5.host,
    host = _ref5$host === void 0 ? window.location.host : _ref5$host;
  return host.includes('infojobs.it') ? 'infojobs_it' : 'infojobs';
}
function getUserId() {
  var _document$cookie$spli;
  var userId = (_document$cookie$spli = document.cookie.split(';').map(function (cookie) {
    var _cookie$split = cookie.split('='),
      key = _cookie$split[0],
      value = _cookie$split[1];
    if (key.trim() === 'ajs_user_id') {
      return value;
    }
    return null;
  }).filter(Boolean)) == null ? void 0 : _document$cookie$spli[0];
  return userId ? {
    user_id: userId
  } : {};
}
function getGoogleAnalyticsConfigByEnv(_ref6) {
  var _ref6$env = _ref6.env,
    env = _ref6$env === void 0 ? 'production' : _ref6$env,
    host = _ref6.host;
  if (env !== 'production') {
    return {};
  }
  return {
    googleAnalyticsMeasurementId: 'G-7SHGGRXFWG',
    googleAnalyticsConfig: _extends({
      user_properties: {
        tenant: getTenant({
          host: host
        })
      }
    }, getUserId())
  };
}
export default (function (dependencies) {
  var _window$__mpi$segment, _window$__mpi$segment2, _window$__mpi$segment3;
  window.__SEGMENT_WRAPPER = {
    ADOBE_ORG_ID: '05FF6243578784B37F000101@AdobeOrg',
    TRACKING_SERVER: 'schibstedspain.d3.sc.omtrdc.net'
  };

  // will be accessed by the segment-wrapper
  window.__mpi = window.__mpi || {};
  window.__mpi.segmentWrapper = _extends({}, window.__mpi.segmentWrapper, getGoogleAnalyticsConfigByEnv(dependencies), {
    defaultProperties: _extends({}, (_window$__mpi$segment = window.__mpi.segmentWrapper) == null ? void 0 : _window$__mpi$segment.defaultProperties, {
      site: getSite(dependencies),
      vertical: 'jobs'
    }),
    defaultContext: _extends({}, (_window$__mpi$segment2 = window.__mpi.segmentWrapper) == null ? void 0 : _window$__mpi$segment2.defaultContext, {
      site: getSite(dependencies)
    }),
    getCustomAdobeVisitorId: getVisitorIdCallback(dependencies),
    tcfTrackDefaultProperties: _extends({}, (_window$__mpi$segment3 = window.__mpi.segmentWrapper) == null ? void 0 : _window$__mpi$segment3.tcfTrackDefaultProperties, {
      vertical: 'jobs'
    })
  });
});
